@@ -4,7 +4,7 @@ import click
 
 from .base import instance_option, map_to_click_exceptions
 from ..consts import known_instances, known_instances_rev
-from ..dandiarchive import parse_dandi_url
+from ..dandiarchive import _dandi_url_parser, parse_dandi_url
 
 
 class ChoiceList(click.ParamType):
@@ -30,7 +30,16 @@ class ChoiceList(click.ParamType):
         return "[" + ",".join(self.values) + ",all]"
 
 
-@click.command()
+# The use of f-strings apparently makes this not a proper docstring, and so
+# click doesn't use it unless we explicitly assign it to `help`:
+@click.command(
+    help=f"""\
+Download a file or entire folder from DANDI.
+
+\b
+{_dandi_url_parser.known_patterns}
+    """
+)
 @click.option(
     "-o",
     "--output-dir",
@@ -43,12 +52,12 @@ class ChoiceList(click.ParamType):
     "-e",
     "--existing",
     type=click.Choice(
-        ["error", "skip", "overwrite", "refresh"]
+        ["error", "skip", "overwrite", "overwrite-different", "refresh"]
     ),  # TODO: verify-reupload (to become default)
     help="What to do if a file found existing locally. 'refresh': verify "
     "that according to the size and mtime, it is the same file, if not - "
     "download and overwrite.",
-    default="refresh",
+    default="error",
     show_default=True,
 )
 @click.option(
@@ -76,7 +85,7 @@ class ChoiceList(click.ParamType):
 @click.option(
     "--sync", is_flag=True, help="Delete local assets that do not exist on the server"
 )
-@instance_option()
+@instance_option(default=None)
 # Might be a cool feature, not unlike verifying a checksum, we verify that
 # downloaded file passes the validator, and if not -- alert
 # @click.option(
@@ -94,9 +103,8 @@ class ChoiceList(click.ParamType):
 @click.argument("url", nargs=-1)
 @map_to_click_exceptions
 def download(
-    url, output_dir, existing, jobs, format, download_types, sync, dandi_instance=None
+    url, output_dir, existing, jobs, format, download_types, sync, dandi_instance
 ):
-    """Download a file or entire folder from DANDI"""
     # We need to import the download module rather than the download function
     # so that the tests can properly patch the function with a mock.
     from .. import download
