@@ -1,7 +1,8 @@
 """
-This module provides functionality for parsing URLs for Dandisets & assets on
-Dandi Archive servers and for fetching the objects to which the URLs refer.
-See the docstring for `parse_dandi_url()` for a list of accepted URL formats.
+This module provides functionality for parsing URLs and other resource
+identifiers for Dandisets & assets on Dandi Archive servers and for fetching
+the objects to which the URLs refer.  See :ref:`resource_ids` for a list of
+accepted URL formats.
 
 Basic operation begins by calling `parse_dandi_url()` on a URL in order to
 acquire a `ParsedDandiURL` instance, which can then be used to obtain the
@@ -35,7 +36,13 @@ from pydantic import AnyHttpUrl, BaseModel, parse_obj_as, validator
 import requests
 
 from . import get_logger
-from .consts import DANDISET_ID_REGEX, RETRY_STATUSES, VERSION_REGEX, known_instances
+from .consts import (
+    DANDISET_ID_REGEX,
+    PUBLISHED_VERSION_REGEX,
+    RETRY_STATUSES,
+    VERSION_REGEX,
+    known_instances,
+)
 from .dandiapi import BaseRemoteAsset, DandiAPIClient, RemoteDandiset
 from .exceptions import FailedToConnectError, NotFoundError, UnknownURLError
 from .utils import get_instance
@@ -363,9 +370,12 @@ class _dandi_url_parser:
         # TODO: Later should better conform to our API, so we could allow
         #       for not only "dandiarchive.org" URLs
         (
-            re.compile(r"DANDI:.*"),
-            {"rewrite": lambda x: "https://identifiers.org/" + x},
-            "DANDI:<dandiset id>",
+            re.compile(
+                fr"DANDI:{DANDISET_ID_REGEX}(?:/{PUBLISHED_VERSION_REGEX})?",
+                flags=re.I,
+            ),
+            {"rewrite": lambda x: "https://identifiers.org/" + x.lower()},
+            "DANDI:<dandiset id>[/<version id>]",
         ),
         (
             re.compile(r"https?://dandiarchive\.org/.*"),
@@ -373,9 +383,13 @@ class _dandi_url_parser:
             "https://dandiarchive.org/...",
         ),
         (
-            re.compile(r"https?://identifiers\.org/DANDI:.*"),
+            re.compile(
+                fr"https?://identifiers\.org/DANDI:{DANDISET_ID_REGEX}"
+                fr"(?:/{PUBLISHED_VERSION_REGEX})?",
+                flags=re.I,
+            ),
             {"handle_redirect": "pass"},
-            "https://identifiers.org/DANDI:<dandiset id>",
+            "https://identifiers.org/DANDI:<dandiset id>[/<version id>]",
         ),
         (
             re.compile(
@@ -466,55 +480,8 @@ class _dandi_url_parser:
     @classmethod
     def parse(cls, url: str, *, map_instance: bool = True) -> ParsedDandiURL:
         """
-        Parse a Dandi Archive URL and return a `ParsedDandiURL` instance.
-
-        The accepted URL formats are as follows.  Text in [brackets] is
-        optional.  A ``server`` field is a base API, GUI, or redirector URL for
-        a registered Dandi Archive instance.  If an optional ``version`` field
-        is omitted from a URL, the given Dandiset's most recent published
-        version, if any, or else its draft version will be used.
-
-        - :samp:`https://identifiers.org/DANDI:{dandiset-id}` when it redirects
-          to one of the other URL formats
-
-        - :samp:`DANDI:{dandiset-id}` — Abbreviation for the above
-
-        - Any ``https://dandiarchive.org/`` or
-          ``https://*dandiarchive-org.netflify.app/`` URL which redirects to
-          one of the other URL formats
-
-        - :samp:`https://{server}[/api]/[#/]dandiset/{dandiset-id}[/{version}][/files[?location={path}]]`
-          — If ``path`` is not specified, the URL refers to a Dandiset and is
-          converted to a `DandisetURL`.  If ``path`` is specified and it ends
-          with a forward slash, the URL refers to an asset folder and is
-          converted to an `AssetFolderURL` instance; if it does not end with a
-          slash, it refers to a single asset and is converted to an
-          `AssetItemURL` instance.
-
-        - :samp:`https://{server}[/api]/dandisets/{dandiset-id}[/versions[/{version}]]`
-          — Refers to a Dandiset and is converted to a `DandisetURL`
-
-        - :samp:`https://{server}[/api]/assets/{asset-id}[/download]` — Refers
-          to a single asset by identifier and is converted to a
-          `BaseAssetIDURL`
-
-        - :samp:`https://{server}[/api]/dandisets/{dandiset-id}/versions/{version}/assets/{asset-id}[/download]`
-          — Refers to a single asset and is converted to an `AssetIDURL`
-
-        - :samp:`https://{server}[/api]/dandisets/{dandiset-id}/versions/{version}/assets/?path={path}`
-          — Refers to all assets in the given Dandiset whose paths begin with
-          the prefix ``path``; converted to an `AssetPathPrefixURL`
-
-        - :samp:`dandi://{instance-name}/{dandiset-id}[@{version}][/{path}]`,
-          where ``instance-name`` is the name of a registered Dandi Archive
-          instance.  If ``path`` is not specified, the URL refers to a Dandiset
-          and is converted to a `DandisetURL`.  If ``path`` is specified and it
-          ends with a forward slash, the URL refers to an asset folder and is
-          converted to an `AssetFolderURL` instance; if it does not end with a
-          slash, it refers to a single asset and is converted to an
-          `AssetItemURL` instance.
-
-        - Any other HTTPS URL that redirects to one of the above
+        Parse a Dandi Archive URL and return a `ParsedDandiURL` instance.  See
+        :ref:`resource_ids` for the supported URL formats.
 
         :raises UnknownURLError: if the URL is not one of the above
         """
@@ -658,8 +625,15 @@ class _dandi_url_parser:
         i = 0
         while True:
             r = requests.head(url, allow_redirects=True)
-            if r.status_code in (400, *RETRY_STATUSES) and i < 5:
-                sleep(0.1 * 10 ** i)
+            if r.status_code in RETRY_STATUSES and i < 4:
+                delay = 0.1 * 10 ** i
+                lgr.warning(
+                    "HEAD request to %s returned %d; sleeping for %f seconds and then retrying...",
+                    url,
+                    r.status_code,
+                    delay,
+                )
+                sleep(delay)
                 i += 1
                 continue
             elif r.status_code == 404:
