@@ -7,7 +7,7 @@ import time
 import click
 
 from . import lgr
-from .consts import dandiset_identifier_regex, dandiset_metadata_file
+from .consts import DRAFT, dandiset_identifier_regex, dandiset_metadata_file
 from .exceptions import NotFoundError
 from .utils import ensure_datetime, get_instance, pluralize
 
@@ -41,12 +41,13 @@ def upload(
     api_url = instance.api
 
     client = DandiAPIClient(api_url)
+    client.check_schema_version()
     client.dandi_authenticate()
 
     dandiset = APIDandiset(dandiset.path)  # "cast" to a new API based dandiset
 
     ds_identifier = dandiset.identifier
-    remote_dandiset = client.get_dandiset(ds_identifier, "draft")
+    remote_dandiset = client.get_dandiset(ds_identifier, DRAFT)
 
     if not re.match(dandiset_identifier_regex, str(ds_identifier)):
         raise ValueError(
@@ -180,7 +181,7 @@ def upload(
             try:
                 extant = remote_dandiset.get_asset_by_path(str(relpath))
             except NotFoundError:
-                pass
+                extant = None
             else:
                 metadata = extant.get_raw_metadata()
                 local_mtime = ensure_datetime(path_stat.st_mtime)
@@ -251,6 +252,7 @@ def upload(
                 ).json_dict()
             except Exception as e:
                 yield skip_file("failed to extract metadata: %s" % str(e))
+                return
 
             #
             # Upload file
@@ -258,7 +260,7 @@ def upload(
             yield {"status": "uploading"}
             validating = False
             for r in remote_dandiset.iter_upload_raw_asset(
-                path, metadata, jobs=jobs_per_file
+                path, metadata, jobs=jobs_per_file, replace_asset=extant
             ):
                 r.pop("asset", None)  # to keep pyout from choking
                 if r["status"] == "uploading":
@@ -276,6 +278,7 @@ def upload(
         except Exception as exc:
             if devel_debug:
                 raise
+            lgr.exception("Error uploading %s:", relpath)
             # Custom formatting for some exceptions we know to extract
             # user-meaningful message
             message = str(exc)
@@ -344,7 +347,7 @@ def upload(
             relpaths.append("" if rp == "." else rp)
         path_prefix = reduce(os.path.commonprefix, relpaths)
         to_delete = []
-        for asset in remote_dandiset.get_assets_under_path(path_prefix):
+        for asset in remote_dandiset.get_assets_with_path_prefix(path_prefix):
             if (
                 any(p == "" or path_is_subpath(asset.path, p) for p in relpaths)
                 and not Path(dandiset.path, asset.path).exists()
